from jinja2 import Environment as j2Environment, PackageLoader
from src.util.logger import logger


class RenderErr(Exception): pass


class RenderTemplateNotFound(RenderErr): pass


def render_templates(template_type: str, context: dict):
    """
    returns a rendered subject, html_body, and text_body
    """
    logger.debug(f"[{template_type}] Start rendering email template. [{context}]")

    j2e = j2Environment(loader=PackageLoader('src', 'templates'))

    if template_type == 'dailyReport':
        template_paths = ['subj.j2', 'html.j2', 'text.j2']
        retval = []
    elif template_type == 'monthlyReport':
        template_paths = ['html.j2', 'text.j2']
        retval = ["Your Monthly ThreatSight Report"]
    else:
        raise RenderErr(f'Invalid template type: {template_type}')

    for template_path in template_paths:
        templ = j2e.get_template('{}/{}'.format(template_type, template_path))
        retval.append(templ.render(context))

    logger.debug(f"[{template_type}] Finish rendering email template. [{retval}]")
    return retval
